#!python3 -u

from ase.io import read, write
import argparse
import numpy as np
from susmost.acutils import get_unit_cell
import ase.cell

def extract_subcell(atoms, x=0, y=0):
	unit_cell, _ = get_unit_cell(atoms)
	unit_cell = ase.cell.Cell(unit_cell)
	frac = np.floor(unit_cell.scaled_positions(atoms.positions))
	indices = [i for i,f in enumerate(frac) if np.array_equal(f, [x,y,0])]
	subcell = atoms[indices]
	subcell.cell = unit_cell
	subcell.translate(-unit_cell.cartesian_positions([x,y,0]))
	return subcell

parser = argparse.ArgumentParser(description="Extract a single cell from supercell xyz file", formatter_class=argparse.ArgumentDefaultsHelpFormatter)

parser.add_argument('-o', dest='out_filename', nargs='?', default='/dev/stdout',
						help='XYZ file for output, default = /dev/stdout')

parser.add_argument('-X', dest='slab_size_x', type=int, nargs='?', default=None,
					help="Size of the slab along Ox axis, in unit cells, default = read from 'size' key-value from input XYZ file")
					
parser.add_argument('-Y', dest='slab_size_y', type=int, nargs='?', default=None,
					help="Size of the slab along Oy axis, in unit cells, default = read from 'size' key-value from input XYZ file")


parser.add_argument('-x', dest='x_index', type=int, nargs='?',  default=0,
					help="x-coordinate of the subcell to extract, default=0")
					
parser.add_argument('-y', dest='y_index', type=int, nargs='?',  default=0,
					help="y-coordinate of the subcell to extract, default=0")
					
parser.add_argument('filename', help='XYZ file to read')

args = parser.parse_args()


atoms = read(args.filename)
if args.slab_size_x is not None:
	X = args.slab_size_x

if args.slab_size_y is not None:
	Y = args.slab_size_y

if args.slab_size_x is None and args.slab_size_y is None:
	supercell_size = None
elif args.slab_size_x is not None and args.slab_size_y is not None:
	supercell_size = (args.slab_size_x, args.slab_size_y)
else:
	assert False, "args.slab_size_x and args.slab_size_y are inconsistent: {}, {}".format(args.slab_size_x, args.slab_size_y)

subcell = extract_subcell(atoms,  args.x_index, args.y_index, supercell_size)
write(args.out_filename, [subcell], 'extxyz')

