from ase.io import read, write
import sys, argparse, glob, pathlib

parser = argparse.ArgumentParser(description="Create surface samples with adsorption complexes (AC's)", formatter_class=argparse.ArgumentDefaultsHelpFormatter)

parser.add_argument('--samples-dir','-d', dest='samples_dir',
					help='Directory with AC samples.')

args = parser.parse_args()
for fn in glob.glob(f'{args.samples_dir}/sample_???.xyz'):
	sample_path = pathlib.Path(fn)
	a = read(fn)
	try:
		ads = a.arrays['adsorption']
		a1 = a[ads=='a1']
		a2 = a[ads=='a2']
		if sorted(a1.numbers) == sorted(a2.numbers):
			print(f"{fn} IS diffusion")
			slab = a[ads=='s']
			trj = [slab + a1, slab + a2]
			assert len(trj[0])==len(trj[1]) and (trj[0].numbers == trj[1].numbers).all()
			diff_sample_fn = sample_path.parent / f'diff_{sample_path.stem}.xyz'
			write(diff_sample_fn, trj, 'extxyz')
		else:
			print(f"{fn} is NOT diffusion")
	except Exception as err:
		print (f'{fn} is not a pair sample:', err)
		#raise err
