from gpaw import GPAW, Mixer
from ase.io import read, write
from ase.optimize import BFGS, FIRE, GPMin
from ase.constraints import FixAtoms
from sys import argv
import ase
import numpy as np


def minimize(a, traj_fn="optAC.traj"):
	opt = BFGS(a, trajectory = traj_fn)
	opt.run(fmax=0.01)

fn = argv[1]

a = read(fn)

convergence = {'energy': 0.0005, #0.0005,  # eV / electron
				 'density': 1e-4, #1.0e-4,
				 'eigenstates': 4.0e-8,  # eV^2 / electron  This criterion does not affect LCAO calculations.
				 'bands': 'occupied',
				 'forces': float('inf')} # eV / Ang Max

calc_dft = GPAW(xc='C09-vdW', symmetry={'point_group': False}, basis={}, mixer=Mixer(beta=0.05), parallel={'domain':(2,2,1)}, mode='lcao', convergence=convergence, txt=fn+".gpaw.txt")		
a.set_calculator(calc_dft)

e = a.get_potential_energy()
print ("E initial = {}".format(e))
efc = a.get_potential_energy(force_consistent=True)
max_force = np.max(np.linalg.norm(a.get_forces(), axis=1))
ase.parallel.parprint("Energy before relaxation: {}, force consistent: {}, max_force: {}".format(e, efc, max_force))


fixed_zlevel = a.info.get('fixed_zlevel', None)
if fixed_zlevel is not None:
	ase.parallel.parprint("fixed_zlevel =  {}".format(fixed_zlevel))
	fixed_zlevel = float(fixed_zlevel)
	fix_mask = a.positions[:,2] < fixed_zlevel
	constr = FixAtoms(mask = fix_mask)
	a.set_constraint(constr)

minimize(a, fn+".traj")
write(fn+'.rlx.xyz', [a], 'extxyz')
e = a.get_potential_energy()
print ("E relaxed = {}".format(e))
a.set_calculator(None) # clean memory


